# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_model.ipynb.

# %% auto 0
__all__ = ['Model']

# %% ../nbs/00_model.ipynb 3
from huggingface_hub import hf_hub_download
from pathlib import Path
from shapely.geometry import Point
import datetime


# %% ../nbs/00_model.ipynb 5
class Model():
    def __init__(self, 
                 version: str = None, # version to load, if None, load latest
                 local_folder: Path = None, # local path to save model
                 force_fetch: bool = False): # force fetch and overwrite from HG
        
        self.version = version
        if self.version is None:
            self.get_latest_version()
        print(f"Target model {self.version}")
        
        if local_folder is None:
            self.local_folder = Path(f"models/{version}/")
        self.local_folder.mkdir(parents=True, exist_ok=True)

        self.force_fetch = force_fetch
        
        self.model = self.fetch_model()

    def get_latest_version(self):
        """
        Get latest version of model from HG
        """
        self.version = "v0.0"
        print(f"Only one version available for now: {self.version}")
    
    def fetch_model(self):
        """
        Fetch model from HG
        """
        versions = {
            'v0.0': 
            {'filename': 'Clay-v0.0_epoch-02_val-loss-0.52.ckpt'}
        }
        if self.version in versions:
            self.filename = versions[self.version]['filename']
        else:
            raise ValueError(f"Version {self.version} not found")
        
        
        hf_hub_download(repo_id="made-with-clay/Clay",
                        filename=self.filename,
                        cache_dir=self.local_folder,
                        force_download=self.force_fetch)
        
        
        
